@@ -1,3 +1,5 @@
+#' 
+#' 
 VC.est <-
 function( data,
            IxR = has.repl(data), linked = IxR,
@@ -18,7 +20,7 @@ on.exit( options(oo) )
 # the call depending on whether or not random raters
 # are assumed
 if( random.raters )
-  return( MethComp:::VC.est.random( data = data,
+  return( VC.est.random( data = data,
                                      IxR = IxR,
                                      MxI = MxI,
                                   varMxI = varMxI,
@@ -26,7 +28,7 @@ if( random.raters )
                                    print = print,
                               lmecontrol = lmecontrol ) )
 else
-  return( MethComp:::VC.est.fixed ( data = data,
+  return( VC.est.fixed ( data = data,
                                      IxR = IxR,
                                      MxI = MxI,
                                   corMxI = corMxI,
