@@ -28,7 +28,7 @@ if( missing(MxI) ) MxI <- matrix
 if( missing(IxR) ) IxR <- linked
 
 # Package needed for the fitting of the models
-require( nlme )
+# require( nlme )
 
 # Make all variables local to the function environment
 meth <- data$meth
@@ -186,7 +186,7 @@ names( Bias ) <- levels( meth )
 Mu <- summ[grep("item",rownames(summ)),1]
 
 # The two-way random interactions
-vc <- nlme:::VarCorr( m1 )
+vc <- nlme::VarCorr( m1 )
 tau <- matrix( NA, Nm, if(corMxI) Nm else 1 )
 tau.ch <- vc[grep("meth",rownames(vc)),-1,drop=FALSE]
 if(        MxI )                  tau[    ,1] <- as.numeric( tau.ch[    ,1] )
